# %W% %G% %Q%
#  This file controls the conversion of MSC/NASTRAN results into an
#  ARIES Neutral file format.  All possible output conversion are
#  delineated within this file, however the actual results transferred
#  are subject to the analysis solution type and Case Control directives.
#  If the System Administrator or Client wishes to alter the contents
#  of this file to reduce the amount of information transferred, even
#  when present, comment out the translation section by placing a "#"
#  character in column one.
#
#  This area defines the enumeration of the constants used in the object
#  description section.
#
*enumeration
scalar=1    vector=2 sym_tensor=3 gen_tensor=4;
real=1      complex=2;
non_field=0 field=1  field_strain=2;
connect=1   con_id=2  sngl_val=3  gauss=4;
single=0    multiple=1;
global=0    displacement=1 element=2 unknown=3 Aries=4;
*end
#
#  The following are grid dominant output quantities assumed to be in the
#  MSC/NASTRAN global coordinate system.  The quantities will be by default
#  transformed to MSC/NASTRAN basic ( Aries global) reference system.  The
#  designator "displacement" will leave them in global.  The "element" system
#  is not applicable for node data recover.
#
#############################
if (PRODUCT = NASTRAN) then
###################################
if (ANALYSIS != (HEAT_TRANSFER | TRANSIENT_HEAT_TRANSFER)) then
#
*fem_results_data_on_nodes
DISPLACEMENT
vector real field single global;
L
DELTA
DISP DT1 DT2 DT3;
*break
ROTATION
vector real field single global;
rad
ANGLE
DR1 DR2 DR3;
*end
#
*fem_results_data_on_nodes
VELOCITY
vector real field single global;
L/T
DELTA
VELO VT1 VT2 VT3;
*break
ROTATIONAL_VELOCITY
vector real field single global;
rad/T
ANGLE
VR1 VR2 VR3;
*end
#
*fem_results_data_on_nodes
ACCELERATION
vector real field single global;
L/(T*T)
DELTA
ACCE AT1 AT2 AT3;
*break
ROTATIONAL_ACCELERATION
vector real field single global;
rad/(T*T)
ANGLE
AR1 AR2 AR3;
*end
#
*fem_results_data_on_nodes
REACTION_FORCE
vector real non_field single global;
F
FORCE
SPCF QT1 QT2 QT3;
*break
REACTION_MOMENT
vector real non_field single global;
L*F
MOMENT
QR1 QR2 QR3;
*end
#
*fem_results_data_on_nodes
APPLIED_FORCE
vector real non_field single global;
F
FORCE
LOAD PT1 PT2 PT3;
*break
APPLIED_MOMENT
vector real non_field single global;
L*F
MOMENT
PR1 PR2 PR3;
*end
#
#
#  The next section describes element data recovery.  Most data recovery
#  is converted into a mathematical concept of either scalar, vector or
#  tensor within the basic (ARIES global) reference system.  The primary
#  constant controlling this converion is the "global" keyword.  Currently
#  unknown and ARIES are not implemented.  For those object designated
#  to be in element already, there may not exist consistent transformation
#  matrices to convert the element results to basic.
#
#  Also note that certain of the translations are analysis approach
#  sensitive.
#
###############################################################
if (ANALYSIS != (NONLINEAR_STATICS | NONLINEAR_TRANSIENT)) then
#
*fem_results_data_on_elements
STRESS
sym_tensor real con_id field multiple global;
F/(L*L)
SIGMA
SQD4X>SQD4 SX2 SY2 0 T2 0 0   SX1 SY1 0 T1 0 0;
STR3       SX2 SY2 0 T2 0 0   SX1 SY1 0 T1 0 0;
SQDR       SX2 SY2 0 T2 0 0   SX1 SY1 0 T1 0 0;
STRR       SX2 SY2 0 T2 0 0   SX1 SY1 0 T1 0 0;
SQD8       SX2 SY2 0 T2 0 0   SX1 SY1 0 T1 0 0;
STR6       SX2 SY2 0 T2 0 0   SX1 SY1 0 T1 0 0;
SHEX SX SY SZ TXY TYZ TZX;
SPEN SX SY SZ TXY TYZ TZX;
STET SX SY SZ TXY TYZ TZX;
SPSG SX SY SZ TXY TYZ TZX;
*end
#
#######################################
if (MODEL_TYPE = PLANE_STRAIN) then
#
*fem_results_data_on_elements
NASTRAN_VON_MISES_STRESS
scalar real con_id field multiple global;
F/(L*L)
SIGMA
SQD4X>SQD4 TM2 TM1;
STR3       TM2 TM1;
SQDR       TM2 TM1;
STRR       TM2 TM1;
SQD8       TM2 TM1;
STR6       TM2 TM1;
SHEX OCT;
SPEN OCT;
STET OCT;
SPSG OCT;
*end
endif
#
#######################################
*fem_results_data_on_elements
STRAIN
sym_tensor real con_id field_strain multiple global;
L/L
EPSILON
EQD4X>EQD4 EX2 EY2 0 ET2 0 0   EX1 EY1 0 ET1 0 0;
ETR3       EX2 EY2 0 ET2 0 0   EX1 EY1 0 ET1 0 0;
EQDR       EX2 EY2 0 ET2 0 0   EX1 EY1 0 ET1 0 0;
ETRR       EX2 EY2 0 ET2 0 0   EX1 EY1 0 ET1 0 0;
EQD8       EX2 EY2 0 ET2 0 0   EX1 EY1 0 ET1 0 0;
ETR6       EX2 EY2 0 ET2 0 0   EX1 EY1 0 ET1 0 0;
EHEX EX EY EZ ETXY ETYZ ETZX;
EPEN EX EY EZ ETXY ETYZ ETZX;
ETET EX EY EZ ETXY ETYZ ETZX;
EPSG EX EY EZ ETXY ETYZ ETZX;
*end
#
*fem_results_data_on_elements
LINE_ELEMENT_STRESS
sym_tensor real con_id non_field single global;
F/(L*L)
SIGMA
SCON AS 0 0 0 0 0;
SROD AS 0 0 0 0 0;
STUB AS 0 0 0 0 0;
*end
#
#######################################
if (BEAM_RECOVERY > 0) then
#
*fem_results_data_on_elements
BEAM_STRESS_POINT_1
sym_tensor real con_id non_field single global;
F/(L*L)
SIGMA
SBEM (GRID) SXC 0 0 0 0 0;
SBAR SXCA 0 0 0 0 0 / SXCB 0 0 0 0 0;
*end
endif
#
#######################################
if (BEAM_RECOVERY > 1) then
#
*fem_results_data_on_elements
BEAM_STRESS_POINT_2
sym_tensor real con_id non_field single global;
F/(L*L)
SIGMA
SBEM (GRID) SXD 0 0 0 0 0;
SBAR SXDA 0 0 0 0 0 / SXDB 0 0 0 0 0;
*end
endif
#
#######################################
if (BEAM_RECOVERY > 2) then
#
*fem_results_data_on_elements
BEAM_STRESS_POINT_3
sym_tensor real con_id non_field single global;
F/(L*L)
SIGMA
SBEM (GRID) SXE 0 0 0 0 0;
SBAR SXEA 0 0 0 0 0 / SXEB 0 0 0 0 0;
*end
endif
#
#######################################
if (BEAM_RECOVERY > 3) then
#
*fem_results_data_on_elements
BEAM_STRESS_POINT_4
sym_tensor real con_id non_field single global;
F/(L*L)
SIGMA
SBEM (GRID) SXF 0 0 0 0 0;
SBAR SXFA 0 0 0 0 0 / SXFB 0 0 0 0 0;
*end
endif
#
########################################
if (BEAM_RECOVERY = 0) then
#
*fem_results_data_on_elements
BEAM_ELEMENT_STRESS
sym_tensor real con_id non_field single global;
F/(L*L)
SIGMA
SBEM (GRID) SXC 0 0 0 0 0;
SBAR SXCA 0 0 0 0 0 / SXCB 0 0 0 0 0;
*end
endif
#
########################################
if (ANALYSIS != FREQUENCY_RESPONSE) then
#
*fem_results_data_on_elements
FORCES_ON_GAPS
vector real con_id non_field single global;
F
FORCE
NGAP CPX SHY SHZ | FGAP  FX SFY SFZ;
*break
DISPLACEMENTS_ON_GAPS
vector real con_id non_field single global;
L
DELTA
AU SHV SHW  |  U V W;
*end
#
*fem_results_data_on_elements
ERROR
scalar real con_id field single global;
L/L
ERROR
IPSG ERROR;
*break
PX_ORDER
scalar real con_id field single global;
L/L
ORDER
PX;
*break
PY_ORDER
scalar real con_id field single global;
L/L
ORDER
PY;
*break
PZ_ORDER
scalar real con_id field single global;
L/L
ORDER
PZ;
*end
#
endif
endif
##############################################################
if (ANALYSIS = (NONLINEAR_STATICS | NONLINEAR_TRANSIENT)) then
#
# Plane strain for nonlinear only puts out top fiber
if (MODEL_TYPE = PLANE_STRAIN) then
*fem_results_data_on_elements
STRESS
sym_tensor real con_id field single global;
F/(L*L)
SIGMA
NQD4   SX1 SY1 SZ1 T1 0 0  |
  SQD4 SX1 SY1 0   T1 0 0;
NTR3   SX1 SY1 SZ1 T1 0 0  |
  STR3 SX1 SY1 0 T1 0 0;
SQDR   SX1 SY1 0 T1 0 0;
STRR   SX1 SY1 0 T1 0 0;
SQD8   SX1 SY1 0 T1 0 0;
STR6   SX1 SY1 0 T1 0 0;
NHEX SX SY SZ TXY TYZ TZX  |  SHEX SX SY SZ TXY TYZ TZX;
NPEN SX SY SZ TXY TYZ TZX  |  SPEN SX SY SZ TXY TYZ TZX;
NTET SX SY SZ TXY TYZ TZX  |  STET SX SY SZ TXY TYZ TZX;
*break
EQUIVALENT_STRESS
scalar  real con_id field single global;
F/(L*L)
SIGMA
ES  |  TM1;
ES  |  TM1;
TM1;
TM1;
TM1;
TM1;
SE | OCT;
SE | OCT;
SE | OCT;
*break
EFFECTIVE_STRAIN
scalar  real con_id field single global;
L/L
EPSILON
EPS1  | 0;
EPS1  | 0;
0;
0;
0;
0;
EPS | 0;
EPS | 0;
EPS | 0;
# Follow has been made inactive due to non-support from pre-
#*break
#EFFECTIVE_CREEP_STRAIN
#scalar  real con_id field single global;
#L/L
#EPSILON
#ECS1  | 0;
#ECS1  | 0;
#0;
#0;
#0;
#0;
#ECS | 0;
#ECS | 0;
#ECS | 0;
*end
endif
#########################
if (MODEL_TYPE != PLANE_STRAIN) then
*fem_results_data_on_elements
STRESS
sym_tensor real con_id field multiple global;
F/(L*L)
SIGMA
NQD4   SX2 SY2 SZ2 T2 0 0   SX1 SY1 SZ1 T1 0 0  |
  SQD4 SX2 SY2 0   T2 0 0   SX1 SY1 0   T1 0 0;
NTR3   SX2 SY2 SZ2 T2 0 0   SX1 SY1 SZ1 T1 0 0  |
  STR3 SX2 SY2 0 T2 0 0     SX1 SY1 0 T1 0 0;
SQDR   SX2 SY2 0 T2 0 0     SX1 SY1 0 T1 0 0;
STRR   SX2 SY2 0 T2 0 0     SX1 SY1 0 T1 0 0;
SQD8   SX2 SY2 0 T2 0 0     SX1 SY1 0 T1 0 0;
STR6   SX2 SY2 0 T2 0 0     SX1 SY1 0 T1 0 0;
NHEX SX SY SZ TXY TYZ TZX  |  SHEX SX SY SZ TXY TYZ TZX;
NPEN SX SY SZ TXY TYZ TZX  |  SPEN SX SY SZ TXY TYZ TZX;
NTET SX SY SZ TXY TYZ TZX  |  STET SX SY SZ TXY TYZ TZX;
*break
EQUIVALENT_STRESS
scalar  real con_id field multiple global;
F/(L*L)
SIGMA
ES2 ES  |  TM2 TM1;
ES2 ES  |  TM2 TM1;
TM2 TM1;
TM2 TM1;
TM2 TM1;
TM2 TM1;
SE | OCT;
SE | OCT;
SE | OCT;
*break
EFFECTIVE_STRAIN
scalar  real con_id field multiple global;
L/L
EPSILON
EPS2 EPS1  | 0 0;
EPS2 EPS1  | 0 0;
0 0;
0 0;
0 0;
0 0;
EPS | 0;
EPS | 0;
EPS | 0;
# Follow has been made inactive due to non-support from pre-
#*break
#EFFECTIVE_CREEP_STRAIN
#scalar  real con_id field multiple global;
#
#EPSILON
#ECS2 ECS1  | 0 0;
#ECS2 ECS1  | 0 0;
#0 0;
#0 0;
#0 0;
#0 0;
#ECS | 0;
#ECS | 0;
#ECS | 0;
*end
endif
#
*fem_results_data_on_elements
FORCES_ON_GAPS
vector real con_id non_field single global;
F
FORCE
NGAP CPX SHY SHZ;
*break
DISPLACEMENTS_ON_GAPS
vector real con_id non_field single global;
L
DELTA
AU SHV SHW;
*end
#
*fem_results_data_on_elements
LINE_ELEMENT_STRESS
sym_tensor real con_id non_field single global;
F/(L*L)
SIGMA
NCON AS 0 0 0 0 0  |  SCON AS 0 0 0 0 0;
NROD AS 0 0 0 0 0  |  SROD AS 0 0 0 0 0;
NTUB AS 0 0 0 0 0  |  STUB AS 0 0 0 0 0;
*break
LINE_ELEMENT_EQUIVALENT_STRESS
scalar  real con_id field single global;
F/(L*L)
SIGMA
SE | 0;
SE | 0;
SE | 0;
*break
LINE_EFFECTIVE_STRAIN
scalar  real con_id field single global;
L/L
EPSILON
EPS | 0;
EPS | 0;
EPS | 0;
# Follow has been made inactive due to non-support from pre-
#*break
#LINE_EFFECTIVE_CREEP_STRAIN
#scalar  real con_id field single global;
#L/L
#EPSILON
#ECS | 0;
#ECS | 0;
#ECS | 0;
*end
#
#######################################
if (BEAM_RECOVERY > 0) then
#
*fem_results_data_on_elements
BEAM_STRESS_POINT_1
sym_tensor real con_id non_field single global;
F/(L*L)
SIGMA
NBEM (GRID) SXC 0 0 0 0 0  |  SBEM (GRID) SXC 0 0 0 0 0;
*end
endif
#
#######################################
if (BEAM_RECOVERY > 1) then
#
*fem_results_data_on_elements
BEAM_STRESS_POINT_2
sym_tensor real con_id non_field single global;
F/(L*L)
SIGMA
NBEM (GRID) SXD 0 0 0 0 0  |  SBEM (GRID) SXD 0 0 0 0 0;
*end
endif
#
#######################################
if (BEAM_RECOVERY > 2) then
#
*fem_results_data_on_elements
BEAM_STRESS_POINT_3
sym_tensor real con_id non_field single global;
F/(L*L)
SIGMA
NBEM (GRID) SXE 0 0 0 0 0  |  SBEM (GRID) SXE 0 0 0 0 0;
*end
endif
#
#######################################
if (BEAM_RECOVERY > 3) then
#
*fem_results_data_on_elements
BEAM_STRESS_POINT_4
sym_tensor real con_id non_field single global;
F/(L*L)
SIGMA
NBEM (GRID) SXF 0 0 0 0 0  |  SBEM (GRID) SXF 0 0 0 0 0;
*end
endif
#
########################################
if (BEAM_RECOVERY = 0) then
#
*fem_results_data_on_elements
BEAM_ELEMENT_STRESS
sym_tensor real con_id non_field single global;
F/(L*L)
SIGMA
NBEM (GRID) SXC 0 0 0 0 0  |  SBEM (GRID) SXC 0 0 0 0 0;
*end
endif
#
*fem_results_data_on_elements
BEAM_ELEMENT_EQUIVALENT_STRESS
scalar  real con_id field single global;
F/(L*L)
SIGMA
NBEM SEC | NBEM 0;
*break
BEAM_EFFECTIVE_STRAIN
scalar  real con_id field single global;
L/L
EPSILON
EPEC | 0;
# Follow has been made inactive due to non-support from pre-
#*break
#BEAM_EFFECTIVE_CREEP_STRAIN
#scalar  real con_id field single global;
#L/L
#EPSILON
#ECEC | 0;
*end
#  Following is prototype for non-linear strain recovery
#*fem_results_data_on_elements
#STRAIN
#sym_tensor real con_id field_strain multiple global;
#L/L
#EPSILON
#NQD4   EX2 EY2 EZ2 ET2 0 0   EX1 EY1 EZ1 ET1 0 0  |
#  EQD4 EX2 EY2 0   ET2 0 0   EX1 EY1 0   ET1 0 0;
#NTR3   EX2 EY2 EZ2 ET2 0 0   EX1 EY1 EZ1 ET1 0 0  |
#  ETR3 EX2 EY2 0   ET2 0 0   EX1 EY1 0   ET1 0 0;
#EQDR   EX2 EY2 0   ET2 0 0   EX1 EY1 0   ET1 0 0;
#ETRR   EX2 EY2 0   ET2 0 0   EX1 EY1 0   ET1 0 0;
#EQD8   EX2 EY2 0   ET2 0 0   EX1 EY1 0   ET1 0 0;
#ETR6   EX2 EY2 0   ET2 0 0   EX1 EY1 0   ET1 0 0;
#NHEX  EX EY EZ EXY EYZ EZX  |  EHEX  EX EY EZ ETXY ETYZ ETZX;
#NPEN  EX EY EZ EXY EYZ EZX  |  EPEN  EX EY EZ ETXY ETYZ ETZX;
#NTET  EX EY EZ EXY EYZ EZX  |  ETET  EX EY EZ ETXY ETYZ ETZX;
#*end
#
endif
#####
#
*fem_results_data_on_elements
STRESS
sym_tensor real con_id field single global;
F/(L*L)
SIGMA
STX6 RS AXS AS SS 0 0;
*end
#
*fem_results_data_on_elements
ELASTIC_ELEMENT_STRESS
scalar real con_id non_field single global;
F/(L*L)
SIGMA
SELS S;
*end
#
*fem_results_data_on_elements
SHEAR_ELEMENT_MAXIMUM_STRESS
scalar real con_id field single global;
F/(L*L)
SIGMA
SSHR TM;
*break
SHEAR_ELEMENT_AVERAGE_STRESS
scalar real con_id field single global;
F/(L*L)
SIGMA
TA;
*end
#
#  Element Force Data Recovery
#
*fem_results_data_on_elements
SHELL_FORCE_RESULTANT
sym_tensor real con_id field single global;
F/L
FORCE
FQD4X>FQD4 MX MY 0 MXY 0 0;
FTR3       MX MY 0 MXY 0 0;
FQDR       MX MY 0 MXY 0 0;
FTRR       MX MY 0 MXY 0 0;
FQD8       MX MY 0 MXY 0 0;
FTR6       MX MY 0 MXY 0 0;
*break
SHELL_MOMENT_RESULTANT
sym_tensor real con_id field single global;
(F*L)/L
MOMENT
BMX BMY 0 BMXY 0 0;
BMX BMY 0 BMXY 0 0;
BMX BMY 0 BMXY 0 0;
BMX BMY 0 BMXY 0 0;
BMX BMY 0 BMXY 0 0;
BMX BMY 0 BMXY 0 0;
*break
SHELL_SHEAR
vector real con_id field single global;
F/L
FORCE
TX TY 0;
TX TY 0;
TX TY 0;
TX TY 0;
TX TY 0;
TX TY 0;
*end
#
*fem_results_data_on_elements
LINE_ELEMENT_FORCE
sym_tensor real con_id non_field single global;
F
FORCE
FCON AF 0 0 0 0 0;
FROD AF 0 0 0 0 0;
FTUB AF 0 0 0 0 0;
*end
#
*fem_results_data_on_elements
BEAM_ELEMENT_FORCE
sym_tensor real con_id non_field single global;
F
FORCE
FBEM (GRID) AF 0 0 W1 0 W2;
FBAR  BAF 0 0 TP1 0 TP2;
*break
BEAM_ELEMENT_MOMENT
sym_tensor real con_id non_field single global;
F*L
MOMENT
(GRID) TT 0 0 BM2 0 BM1;
BT 0 0 BM2A 0 BM1A / BT 0 0 BM2B 0 BM1B;
*end
#
*fem_results_data_on_elements
SHEAR_ELEMENT_FORCE
vector real con_id non_field single element;
F
FORCE
FSHR F21 F41 K1 / F12 F32 K2 / F23 F43 K3 / F14 F34 K4;
*end
#
####################################
if (ANALYSIS = STATIC_ANALYSIS) then
#
*fem_results_data_on_elements
STRAIN_ENERGY
scalar real con_id field single global;
F*L
ENERGY
UBAR ENERGY;
UBEM ENERGY;
UCON ENERGY;
UELS ENERGY;
UGAP ENERGY;
UHEX ENERGY;
UPEN ENERGY;
UQD4 ENERGY;
UQD8 ENERGY;
UQDR ENERGY;
UROD ENERGY;
USHR ENERGY;
UTET ENERGY;
UTRR ENERGY;
UTR3 ENERGY;
UTR6 ENERGY;
UTUB ENERGY;
UTX6 ENERGY;
*break
STRAIN_ENERGY_DENSITY
scalar real con_id field single global;
(F*L)/(L*L*L)
ENERGY_DENSITY
DEN;
DEN;
DEN;
DEN;
DEN;
DEN;
DEN;
DEN;
DEN;
DEN;
DEN;
DEN;
DEN;
DEN;
DEN;
DEN;
DEN;
DEN;
*end
#
endif
endif
#####
#
##################################
if (ANALYSIS = (HEAT_TRANSFER | TRANSIENT_HEAT_TRANSFER)) then
#
if (VERSION < 68) then
#
#  Note DBC Module did not support Thermal at these releases
#
*fem_results_data_on_nodes
TEMPERATURES
scalar real field single global;
R
TEMPERATURE
DISP DT1;
*end
#
*fem_results_data_on_nodes
BC_REACTION
scalar real non_field single global;
E/T
HEAT_FLOW
SPCF QT1;
*end
#
*fem_results_data_on_nodes
APPLIED_HEAT
scalar real non_field single global;
E/T
HEAT_FLOW
LOAD PT1;
*end
#
*fem_results_data_on_elements
THERMAL_GRADIENT
vector real con_id field single global;
R/L
GRADIENT
internal_1;
*break
THERMAL_FLUX
vector real con_id field single global;
E/T/(L*L)
FLUX
*end
#
endif
#
if (VERSION >= 68) then
#
*fem_results_data_on_nodes
TEMPERATURES
scalar real field single global;
R
TEMPERATURE
THER TEMP;
*end
#
*fem_results_data_on_nodes
BC_REACTION
scalar real non_field single global;
E/T
HEAT_FLOW
HTFF HFOW;
*end
#
*fem_results_data_on_nodes
APPLIED_HEAT
scalar real non_field single global;
E/T
HEAT_FLOW
HTFL HFOW;
*end
#
*fem_results_data_on_elements
BOUNDARY_APPLIED_FLOW
scalar real con_id field single global;
E/T
BOUNDARY_APPLIED_FLOW
ZBAR APPLD;
ZBEM APPLD;
ZCON APPLD;
ZHEX APPLD;
ZPEN APPLD;
ZQD4 APPLD;
ZQD8 APPLD;
ZROD APPLD;
ZTET APPLD;
ZTR3 APPLD;
ZTR6 APPLD;
ZTX6 APPLD;
ZTUB APPLD;
*break
BOUNDARY_FREE_CONVECTION
scalar real con_id field single global;
E/T
BOUNDARY_FREE_CONVECTION
FREEC;
FREEC;
FREEC;
FREEC;
FREEC;
FREEC;
FREEC;
FREEC;
FREEC;
FREEC;
FREEC;
FREEC;
FREEC;
*break
BOUNDARY_FORCED_CONVECTION
scalar real con_id field single global;
E/T
BOUNDARY_FORCED_CONVECTION
FORCEC;
FORCEC;
FORCEC;
FORCEC;
FORCEC;
FORCEC;
FORCEC;
FORCEC;
FORCEC;
FORCEC;
FORCEC;
FORCEC;
FORCEC;
*break
BOUNDARY_RADIATION
scalar real con_id field single global;
E/T
BOUNDARY_RADIATION
RAD;
RAD;
RAD;
RAD;
RAD;
RAD;
RAD;
RAD;
RAD;
RAD;
RAD;
RAD;
RAD;
*break
BOUNDARY_TOTAL_FLOW
scalar real con_id field single global;
E/T
BOUNDARY_TOTAL_FLOW
TOTAL;
TOTAL;
TOTAL;
TOTAL;
TOTAL;
TOTAL;
TOTAL;
TOTAL;
TOTAL;
TOTAL;
TOTAL;
TOTAL;
TOTAL;
*end
#
*fem_results_data_on_elements
THERMAL_GRADIENT
vector real con_id field single global;
R/L
GRADIENT
QBAR XGRAD YGRAD ZGRAD;
QBEM XGRAD YGRAD ZGRAD;
QCON XGRAD YGRAD ZGRAD;
QROD XGRAD YGRAD ZGRAD;
QQD4 XGRAD YGRAD ZGRAD;
QTR3 XGRAD YGRAD ZGRAD;
QQD8 XGRAD YGRAD ZGRAD;
QTR6 XGRAD YGRAD ZGRAD;
QHEX XGRAD YGRAD ZGRAD;
QPEN XGRAD YGRAD ZGRAD;
QTET XGRAD YGRAD ZGRAD;
QTX6 XGRAD YGRAD ZGRAD;
*break
THERMAL_FLUX
vector real con_id field single global;
E/T/(L*L)
FLUX
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
*end
#
endif
endif
endif
if (PRODUCT = EMAS) then
#
# ***NOTE***NOTE***NOTE***NOTE***NOTE***NOTE***NOTE***NOTE***
# When customizing these output requests, care must be taken!
#
# For instance, if you wanted to get power loss density
# at the center of each element to use in MSC/Nastran QVOL
# records, look at the rule for POWER_LOSS_DENSITY.
#
#        *fem_results_data_on_elements
#        POWER_LOSS_DENSITY
#        scalar real con_id field single global;
#        joule/(sec*meter*meter*meter)
#        POWER_LOSS
#        OHXC>OHEX PLD;
#        OLNC>OLIN PLD;
#        OLXC>OLIX PLD;
#        OPNC>OPEN PLD;
#        OQDC>OQUD PLD;
#        OQXC>OQDX PLD;
#        OTEC>OTET PLD;
#        OTRC>OTRI PLD;
#        OTXC>OTRX PLD;
#        *end
#
# The request "OHXC>OHEX PLD;" means:
#
#    o If you can find relation OHXC, use it,
#       otherwise look for the OHEX relation
#
#    o What does this cryptic OHXC and OHEX relation stuff mean?
#        O         -> Power loss density
#         HXC      -> 8 values - one for each corner node of Hexa
#         HEX      -> 1 value  - element centroid of Hexa
#             PLD  -> Power loss density field in the relation
#                ; -> End of list of fields for the relation
#
#    o The other element codes are:
#         LNC      -> 2 values - corner nodes of Line
#         LIN      -> 1 value  - element centroid of Line
#         LXC      -> 2 values - corner nodes of LineX
#         LIX      -> 1 value  - element centroid of LineX
#         PNC      -> 6 values - corner nodes of Penta
#         PEN      -> 1 value  - element centroid of Penta
#         QDC      -> 4 values - corner nodes of Quad
#         QUD      -> 1 value  - element centroid of Quad
#         QXC      -> 4 values - corner nodes of QuadX
#         QDX      -> 1 value  - element centroid of QuadX
#         TEC      -> 4 values - corner nodes of Tetra
#         TET      -> 1 value  - element centroid of Tetra
#         TRC      -> 3 values - corner nodes of Tria
#         TRI      -> 1 value  - element centroid of Tria
#         TXC      -> 3 values - corner nodes of TriaX
#         TRX      -> 1 value  - element centroid of TriaX
#
#    o Okay, that describes where the data comes from,
#      now for where the data is going.  That's on the line
#        "scalar real con_id field single global;"
#
#        The third field 'con_id' means a value will be
#        output at each of the grid points, with its grid id.
#        If you choose this, it is safe to use
#        OHXC PLD;       or
#        OHEX PLD;       or
#        OHXC>OHEX PLD;
#
#          When you have 1 input item (an element centroid value),
#          and the output specifies values at each of the grid
#          points, the 1 value is copied to all the grid points.
#
#        The third field 'sngl_val' means 1 value will
#        be output as the element centroid value.
#        If you choose this, you MUST use the element centroid
#        relation.
#        OHEX PLD;
#
#          The reason here is that the number of input items
#          can't exceed the number of output items.  If you
#          try to break this rule, you will not get what you
#          want.
#
# ***NOTE***NOTE***NOTE***NOTE***NOTE***NOTE***NOTE***NOTE***
#
# Because of frequency scaling, we may have to examine
# the units string to figure out the results scale factor.
# If the units require division, use only one /:
#     e.g. If you wanted to do this:
#         volts/sec/sec
# replace it with
#         volts/(sec*sec)
#
#################
# ELECTROSTATIC #
#################
if (ANALYSIS = ELECTROSTATIC) then
*fem_results_data_on_elements
CAPACITOR_DISPLACEMENT_CURRENT
scalar real con_id field single global;
amps
CAP_J_D
DCAP DC;
*end
#
*fem_results_data_on_elements
CAPACITOR_ELECTRIC_ENERGY
scalar real con_id field single global;
joule
CAP_ENERGY
XCAP SEE;
*end
#
*fem_results_data_on_elements
ELECTRIC_ENERGY
scalar real con_id field single global;
joule
ELECTRIC_ENERGY
internal_c;
*end
#
*fem_results_data_on_elements
ELECTRIC_ENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
ELECTRIC_ENERGY
HHXC>HHEX SEED;
HLNC>HLIN SEED;
HLXC>HLIX SEED;
HPNC>HPEN SEED;
HQDC>HQUD SEED;
HQXC>HQDX SEED;
HTEC>HTET SEED;
HTRC>HTRI SEED;
HTXC>HTRX SEED;
*end
#
*fem_results_data_on_elements
ELECTRIC_FIELD
vector real con_id field single global;
volts/meter
E
IHXC>IHEX EFX EFY EFZ;
ILNC>ILIN EFX EFY EFZ;
ILXC>ILIX EFX EFY EFZ;
IPNC>IPEN EFX EFY EFZ;
IQDC>IQUD EFX EFY EFZ;
IQXC>IQDX EFX EFY EFZ;
ITEC>ITET EFX EFY EFZ;
ITRC>ITRI EFX EFY EFZ;
ITXC>ITRX EFX EFY EFZ;
*end
#
*fem_results_data_on_elements
ELECTRIC_FLUX_DENSITY
vector real con_id field single global;
coulombs/(meter*meter)
FLUX
internal_7;
*end
#
#*fem_results_data_on_elements
#ELEMENT_VOLUME
#scalar real con_id field single global;
#meter*meter*meter
#VOLUME
#VHXC>VHEX VOL;
#VLNC>VLIN VOL;
#VLXC>VLIX VOL;
#VPNC>VPEN VOL;
#VQDC>VQUD VOL;
#VQXC>VQDX VOL;
#VTEC>VTET VOL;
#VTRC>VTRI VOL;
#VTXC>VTRX VOL;
#*end
#
*fem_results_data_on_nodes
PHI_POTENTIAL
scalar real field single global;
volts
PHI
GSPD SPD;
*end
#
*fem_results_data_on_nodes
SCALAR_CHARGE_EXCITATION
scalar real field single global;
coulombs
Q_EXCITATION
GPSL PSIL;
*end
#
*fem_results_data_on_nodes
SCALAR_CHARGE_REACTION
scalar real field single global;
coulombs
Q_REACTION
GPSR PSIR;
*end
#
endif
################
# CURRENT_FLOW #
################
if (ANALYSIS = CURRENT_FLOW) then
*fem_results_data_on_elements
CONDUCTION_CURRENT_DENSITY
vector real con_id field single global;
amps/(meter*meter)
J_C
JHXC>JHEX CCDX CCDY CCDZ;
JLNC>JLIN CCDX CCDY CCDZ;
JLXC>JLIX CCDX CCDY CCDZ;
JPNC>JPEN CCDX CCDY CCDZ;
JQDC>JQUD CCDX CCDY CCDZ;
JQXC>JQDX CCDX CCDY CCDZ;
JTEC>JTET CCDX CCDY CCDZ;
JTRC>JTRI CCDX CCDY CCDZ;
JTXC>JTRX CCDX CCDY CCDZ;
*end
#
*fem_results_data_on_elements
ELECTRIC_ENERGY
scalar real con_id field single global;
joule
ELECTRIC_ENERGY
internal_c;
*end
#
*fem_results_data_on_elements
ELECTRIC_ENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
ELECTRIC_ENERGY
HHXC>HHEX SEED;
HLNC>HLIN SEED;
HLXC>HLIX SEED;
HPNC>HPEN SEED;
HQDC>HQUD SEED;
HQXC>HQDX SEED;
HTEC>HTET SEED;
HTRC>HTRI SEED;
HTXC>HTRX SEED;
*end
#
*fem_results_data_on_elements
ELECTRIC_FIELD
vector real con_id field single global;
volts/meter
E
IHXC>IHEX EFX EFY EFZ;
ILNC>ILIN EFX EFY EFZ;
ILXC>ILIX EFX EFY EFZ;
IPNC>IPEN EFX EFY EFZ;
IQDC>IQUD EFX EFY EFZ;
IQXC>IQDX EFX EFY EFZ;
ITEC>ITET EFX EFY EFZ;
ITRC>ITRI EFX EFY EFZ;
ITXC>ITRX EFX EFY EFZ;
*end
#
*fem_results_data_on_elements
ELECTRIC_FLUX_DENSITY
vector real con_id field single global;
coulombs/(meter*meter)
FLUX
internal_7;
*end
#
#*fem_results_data_on_elements
#ELEMENT_VOLUME
#scalar real con_id field single global;
#meter*meter*meter
#VOLUME
#VHXC>VHEX VOL;
#VLNC>VLIN VOL;
#VLXC>VLIX VOL;
#VPNC>VPEN VOL;
#VQDC>VQUD VOL;
#VQXC>VQDX VOL;
#VTEC>VTET VOL;
#VTRC>VTRI VOL;
#VTXC>VTRX VOL;
#*end
#
*fem_results_data_on_nodes
PHI_POTENTIAL
scalar real field single global;
volts
PHI
GSPD SPD;
*end
#
*fem_results_data_on_elements
POWER_LOSS
scalar real con_id field single global;
joule/sec
POWER_LOSS
internal_d;
*end
#
*fem_results_data_on_elements
POWER_LOSS_DENSITY
scalar real con_id field single global;
joule/(sec*meter*meter*meter)
POWER_LOSS
OHXC>OHEX PLD;
OLNC>OLIN PLD;
OLXC>OLIX PLD;
OPNC>OPEN PLD;
OQDC>OQUD PLD;
OQXC>OQDX PLD;
OTEC>OTET PLD;
OTRC>OTRI PLD;
OTXC>OTRX PLD;
*end
#
*fem_results_data_on_elements
RESISTOR_CONDUCTION_CURRENT
scalar real con_id field single global;
amps
RES_J_C
ZRES CC;
*end
#
*fem_results_data_on_elements
RESISTOR_POWER_LOSS
scalar real con_id field single global;
joule/sec
RES_POWER_LOSS
YRES PL;
*end
#
*fem_results_data_on_nodes
SCALAR_NORMAL_CURRENT_EXCITATION
scalar real field single global;
amps
I_EXCITATION
GPHL PHIL;
*end
#
*fem_results_data_on_nodes
SCALAR_NORMAL_CURRENT_REACTION
scalar real field single global;
amps
I_REACTION
GPHR PHIR;
*end
#
endif
#################
# MAGNETOSTATIC #
#################
if (ANALYSIS = MAGNETOSTATIC) then
#*fem_results_data_on_elements
#ELEMENT_VOLUME
#scalar real con_id field single global;
#meter*meter*meter
#VOLUME
#VHXC>VHEX VOL;
#VLNC>VLIN VOL;
#VLXC>VLIX VOL;
#VPNC>VPEN VOL;
#VQDC>VQUD VOL;
#VQXC>VQDX VOL;
#VTEC>VTET VOL;
#VTRC>VTRI VOL;
#VTXC>VTRX VOL;
#*end
#
*fem_results_data_on_elements
MAGNETIC_FIELD
vector real con_id field single global;
amps/meter
H
internal_2;
*end
#
*fem_results_data_on_elements
MAGNETIC_FLUX_DENSITY
vector real con_id field single global;
wb/(meter*meter)
B
MHXC>MHEX MFDX MFDY MFDZ;
MLNC>MLIN MFDX MFDY MFDZ;
MLXC>MLIX MFDX MFDY MFDZ;
MPNC>MPEN MFDX MFDY MFDZ;
MQDC>MQUD MFDX MFDY MFDZ;
MQXC>MQDX MFDX MFDY MFDZ;
MTEC>MTET MFDX MFDY MFDZ;
MTRC>MTRI MFDX MFDY MFDZ;
MTXC>MTRX MFDX MFDY MFDZ;
*end
#
*fem_results_data_on_nodes
MAGNETIC_VECTOR_EXCITATION
vector real field single global;
amps*meter
A_EXCITATION
GVLD VLX VLY VLZ;
*end
#
if (MODEL_TYPE != AXISYMMETRIC) then
*fem_results_data_on_nodes
MAGNETIC_VECTOR_POTENTIAL
vector real field single global;
wb/meter
A
GVPT VPX VPY VPZ;
*end
endif
#
if (MODEL_TYPE = AXISYMMETRIC) then
*fem_results_data_on_nodes
MAGNETIC_VECTOR_POTENTIAL
vector real field single global;
wb/meter
A
internal_9;
*end
endif
#
*fem_results_data_on_nodes
MAGNETIC_VECTOR_REACTION
vector real field single global;
amps*meter
A_REACTION
GVRC VRX VRY VRZ;
*end
#
*fem_results_data_on_elements
STORED_MAGNETIC_ENERGY
scalar real con_id field single global;
joule
MAGNETIC_ENERGY
internal_e;
*break
STORED_MAGNETIC_COENERGY
scalar real con_id field single global;
joule
MAGNETIC_COENERGY
*end
#
*fem_results_data_on_elements
STORED_MAGNETIC_ENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
MAGNETIC_ENERGY
LHXC>LHEX SMED;
LLNC>LLIN SMED;
LLXC>LLIX SMED;
LPNC>LPEN SMED;
LQDC>LQUD SMED;
LQXC>LQDX SMED;
LTEC>LTET SMED;
LTRC>LTRI SMED;
LTXC>LTRX SMED;
*break
STORED_MAGNETIC_COENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
MAGNETIC_COENERGY
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
*end
#
endif
##############################
# MAGNETOSTATIC_CURRENT_FLOW #
##############################
if (ANALYSIS = MAGNETOSTATIC_CURRENT_FLOW) then
*fem_results_data_on_elements
CONDUCTION_CURRENT_DENSITY
vector real con_id field single global;
amps/(meter*meter)
J_C
JHXC>JHEX CCDX CCDY CCDZ;
JLNC>JLIN CCDX CCDY CCDZ;
JLXC>JLIX CCDX CCDY CCDZ;
JPNC>JPEN CCDX CCDY CCDZ;
JQDC>JQUD CCDX CCDY CCDZ;
JQXC>JQDX CCDX CCDY CCDZ;
JTEC>JTET CCDX CCDY CCDZ;
JTRC>JTRI CCDX CCDY CCDZ;
JTXC>JTRX CCDX CCDY CCDZ;
*end
#
*fem_results_data_on_elements
ELECTRIC_ENERGY
scalar real con_id field single global;
joule
ELECTRIC_ENERGY
internal_c;
*end
#
*fem_results_data_on_elements
ELECTRIC_ENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
ELECTRIC_ENERGY
HHXC>HHEX SEED;
HLNC>HLIN SEED;
HLXC>HLIX SEED;
HPNC>HPEN SEED;
HQDC>HQUD SEED;
HQXC>HQDX SEED;
HTEC>HTET SEED;
HTRC>HTRI SEED;
HTXC>HTRX SEED;
*end
#
*fem_results_data_on_elements
ELECTRIC_FIELD
vector real con_id field single global;
volts/meter
E
IHXC>IHEX EFX EFY EFZ;
ILNC>ILIN EFX EFY EFZ;
ILXC>ILIX EFX EFY EFZ;
IPNC>IPEN EFX EFY EFZ;
IQDC>IQUD EFX EFY EFZ;
IQXC>IQDX EFX EFY EFZ;
ITEC>ITET EFX EFY EFZ;
ITRC>ITRI EFX EFY EFZ;
ITXC>ITRX EFX EFY EFZ;
*end
#
*fem_results_data_on_elements
ELECTRIC_FLUX_DENSITY
vector real con_id field single global;
coulombs/(meter*meter)
FLUX
internal_7;
*end
#
#*fem_results_data_on_elements
#ELEMENT_VOLUME
#scalar real con_id field single global;
#meter*meter*meter
#VOLUME
#VHXC>VHEX VOL;
#VLNC>VLIN VOL;
#VLXC>VLIX VOL;
#VPNC>VPEN VOL;
#VQDC>VQUD VOL;
#VQXC>VQDX VOL;
#VTEC>VTET VOL;
#VTRC>VTRI VOL;
#VTXC>VTRX VOL;
#*end
#
*fem_results_data_on_elements
MAGNETIC_FIELD
vector real con_id field single global;
amps/meter
H
internal_2;
*end
#
*fem_results_data_on_elements
MAGNETIC_FLUX_DENSITY
vector real con_id field single global;
wb/(meter*meter)
B
MHXC>MHEX MFDX MFDY MFDZ;
MLNC>MLIN MFDX MFDY MFDZ;
MLXC>MLIX MFDX MFDY MFDZ;
MPNC>MPEN MFDX MFDY MFDZ;
MQDC>MQUD MFDX MFDY MFDZ;
MQXC>MQDX MFDX MFDY MFDZ;
MTEC>MTET MFDX MFDY MFDZ;
MTRC>MTRI MFDX MFDY MFDZ;
MTXC>MTRX MFDX MFDY MFDZ;
*end
#
*fem_results_data_on_nodes
MAGNETIC_VECTOR_EXCITATION
vector real field single global;
amps*meter
A_EXCITATION
GVLD VLX VLY VLZ;
*end
#
if (MODEL_TYPE != AXISYMMETRIC) then
*fem_results_data_on_nodes
MAGNETIC_VECTOR_POTENTIAL
vector real field single global;
wb/meter
A
GVPT VPX VPY VPZ;
*end
endif
#
if (MODEL_TYPE = AXISYMMETRIC) then
*fem_results_data_on_nodes
MAGNETIC_VECTOR_POTENTIAL
vector real field single global;
wb/meter
A
internal_9;
*end
endif
#
*fem_results_data_on_nodes
MAGNETIC_VECTOR_REACTION
vector real field single global;
amps*meter
A_REACTION
GVRC VRX VRY VRZ;
*end
#
*fem_results_data_on_nodes
PHI_POTENTIAL
scalar real field single global;
volts
PHI
GSPD SPD;
*end
#
*fem_results_data_on_elements
POWER_LOSS
scalar real con_id field single global;
joule/sec
POWER_LOSS
internal_d;
*end
#
*fem_results_data_on_elements
POWER_LOSS_DENSITY
scalar real con_id field single global;
joule/(sec*meter*meter*meter)
POWER_LOSS
OHXC>OHEX PLD;
OLNC>OLIN PLD;
OLXC>OLIX PLD;
OPNC>OPEN PLD;
OQDC>OQUD PLD;
OQXC>OQDX PLD;
OTEC>OTET PLD;
OTRC>OTRI PLD;
OTXC>OTRX PLD;
*end
#
*fem_results_data_on_elements
RESISTOR_CONDUCTION_CURRENT
scalar real con_id field single global;
amps
RES_J_C
ZRES CC;
*end
#
*fem_results_data_on_elements
RESISTOR_POWER_LOSS
scalar real con_id field single global;
joule/sec
RES_POWER_LOSS
YRES PL;
*end
#
*fem_results_data_on_nodes
SCALAR_NORMAL_CURRENT_EXCITATION
scalar real field single global;
amps
I_EXCITATION
GPHL PHIL;
*end
#
*fem_results_data_on_nodes
SCALAR_NORMAL_CURRENT_REACTION
scalar real field single global;
amps
I_REACTION
GPHR PHIR;
*end
#
*fem_results_data_on_elements
STORED_MAGNETIC_ENERGY
scalar real con_id field single global;
joule
MAGNETIC_ENERGY
internal_e;
*break
STORED_MAGNETIC_COENERGY
scalar real con_id field single global;
joule
MAGNETIC_COENERGY
*end
#
*fem_results_data_on_elements
STORED_MAGNETIC_ENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
MAGNETIC_ENERGY
LHXC>LHEX SMED;
LLNC>LLIN SMED;
LLXC>LLIX SMED;
LPNC>LPEN SMED;
LQDC>LQUD SMED;
LQXC>LQDX SMED;
LTEC>LTET SMED;
LTRC>LTRI SMED;
LTXC>LTRX SMED;
*break
STORED_MAGNETIC_COENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
MAGNETIC_COENERGY
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
*end
#
endif
#######################
# EM_FREQUENCY_DOMAIN #
#######################
if (ANALYSIS = EM_FREQUENCY_DOMAIN) then
#
*fem_results_data_on_elements
CAPACITOR_DISPLACEMENT_CURRENT
scalar complex con_id field single global;
amps
CAP_J_D
DCAP DC;
*end
#
*fem_results_data_on_elements
CAPACITOR_ELECTRIC_ENERGY
scalar real con_id field single global;
joule
CAP_ENERGY
XCAPR SEE;
*end
#
*fem_results_data_on_elements
CONDUCTION_CURRENT_DENSITY
vector complex con_id field single global;
amps/(meter*meter)
J_C
JHXC>JHEX CCDX CCDY CCDZ;
JLNC>JLIN CCDX CCDY CCDZ;
JLXC>JLIX CCDX CCDY CCDZ;
JPNC>JPEN CCDX CCDY CCDZ;
JQDC>JQUD CCDX CCDY CCDZ;
JQXC>JQDX CCDX CCDY CCDZ;
JTEC>JTET CCDX CCDY CCDZ;
JTRC>JTRI CCDX CCDY CCDZ;
JTXC>JTRX CCDX CCDY CCDZ;
*end
#
*fem_results_data_on_elements
DISPLACEMENT_CURRENT_DENSITY
vector complex con_id field single global;
amps/(meter*meter)
J_D
KHXC>KHEX DCDX DCDY DCDZ;
KLNC>KLIN DCDX DCDY DCDZ;
KLXC>KLIX DCDX DCDY DCDZ;
KPNC>KPEN DCDX DCDY DCDZ;
KQDC>KQUD DCDX DCDY DCDZ;
KQXC>KQDX DCDX DCDY DCDZ;
KTEC>KTET DCDX DCDY DCDZ;
KTRC>KTRI DCDX DCDY DCDZ;
KTXC>KTRX DCDX DCDY DCDZ;
*end
#
*fem_results_data_on_elements
ELECTRIC_ENERGY
scalar real con_id field single global;
joule
ELECTRIC_ENERGY
internal_c;
*end
#
*fem_results_data_on_elements
ELECTRIC_ENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
ELECTRIC_ENERGY
HHXCR>HHEXR SEED;
HLNCR>HLINR SEED;
HLXCR>HLIXR SEED;
HPNCR>HPENR SEED;
HQDCR>HQUDR SEED;
HQXCR>HQDXR SEED;
HTECR>HTETR SEED;
HTRCR>HTRIR SEED;
HTXCR>HTRXR SEED;
*end
#
*fem_results_data_on_elements
ELECTRIC_FIELD
vector complex con_id field single global;
volts/meter
E
IHXC>IHEX EFX EFY EFZ;
ILNC>ILIN EFX EFY EFZ;
ILXC>ILIX EFX EFY EFZ;
IPNC>IPEN EFX EFY EFZ;
IQDC>IQUD EFX EFY EFZ;
IQXC>IQDX EFX EFY EFZ;
ITEC>ITET EFX EFY EFZ;
ITRC>ITRI EFX EFY EFZ;
ITXC>ITRX EFX EFY EFZ;
*end
#
*fem_results_data_on_elements
ELECTRIC_FLUX_DENSITY
vector complex con_id field single global;
coulombs/(meter*meter)
FLUX
internal_8;
*end
#
#*fem_results_data_on_elements
#ELEMENT_VOLUME
#scalar real con_id field single global;
#meter*meter*meter
#VOLUME
#VHXCR>VHEXR VOL;
#VLNCR>VLINR VOL;
#VLXCR>VLIXR VOL;
#VPNCR>VPENR VOL;
#VQDCR>VQUDR VOL;
#VQXCR>VQDXR VOL;
#VTECR>VTETR VOL;
#VTRCR>VTRIR VOL;
#VTXCR>VTRXR VOL;
#*end
#
*fem_results_data_on_elements
INDUCTOR_CONDUCTION_CURRENT
scalar complex con_id field single global;
amps
IND_J_C
ZIND CC;
*end
#
*fem_results_data_on_elements
INDUCTOR_STORED_MAGNETIC_ENERGY
scalar real con_id field single global;
joule
IND_ENERGY
BINDR SME;
*end
#
*fem_results_data_on_elements
MAGNETIC_FIELD
vector complex con_id field single global;
amps/meter
H
internal_3;
*end
#
*fem_results_data_on_elements
MAGNETIC_FLUX_DENSITY
vector complex con_id field single global;
wb/(meter*meter)
B
MHXC>MHEX MFDX MFDY MFDZ;
MLNC>MLIN MFDX MFDY MFDZ;
MLXC>MLIX MFDX MFDY MFDZ;
MPNC>MPEN MFDX MFDY MFDZ;
MQDC>MQUD MFDX MFDY MFDZ;
MQXC>MQDX MFDX MFDY MFDZ;
MTEC>MTET MFDX MFDY MFDZ;
MTRC>MTRI MFDX MFDY MFDZ;
MTXC>MTRX MFDX MFDY MFDZ;
*end
#
*fem_results_data_on_nodes
MAGNETIC_VECTOR_EXCITATION
vector complex field single global;
amps*meter
A_EXCITATION
GVLD VLX VLY VLZ;
*end
#
if (MODEL_TYPE != AXISYMMETRIC) then
*fem_results_data_on_nodes
MAGNETIC_VECTOR_POTENTIAL
vector complex field single global;
wb/meter
A
GVPT VPX VPY VPZ;
*end
endif
#
if (MODEL_TYPE = AXISYMMETRIC) then
*fem_results_data_on_nodes
MAGNETIC_VECTOR_POTENTIAL
vector complex field single global;
wb/meter
A
internal_a;
*end
endif
#
*fem_results_data_on_nodes
MAGNETIC_VECTOR_REACTION
vector complex field single global;
amps*meter
A_REACTION
GVRC VRX VRY VRZ;
*end
#
*fem_results_data_on_nodes
PHI_POTENTIAL
scalar complex field single global;
volts
PHI
GSPD SPD;
*end
#
*fem_results_data_on_elements
POWER_LOSS
scalar real con_id field single global;
joule/sec
POWER_LOSS
internal_d;
*end
#
*fem_results_data_on_elements
POWER_LOSS_DENSITY
scalar real con_id field single global;
joule/(sec*meter*meter*meter)
POWER_LOSS
OHXCR>OHEXR PLD;
OLNCR>OLINR PLD;
OLXCR>OLIXR PLD;
OPNCR>OPENR PLD;
OQDCR>OQUDR PLD;
OQXCR>OQDXR PLD;
OTECR>OTETR PLD;
OTRCR>OTRIR PLD;
OTXCR>OTRXR PLD;
*end
#
*fem_results_data_on_elements
POYNTING_VECTOR_AVERAGE
vector complex con_id field single global;
joule/(meter*meter)
S
internal_4;
*end
#
*fem_results_data_on_elements
POYNTING_VECTOR_REAL_INSTANT
vector real con_id field single global;
joule/(meter*meter)
S
internal_6;
*break
POYNTING_VECTOR_IMAG_INSTANT
vector real con_id field single global;
joule/(meter*meter)
S
*end
#
*fem_results_data_on_nodes
PSI_POTENTIAL
scalar complex field single global;
wb
PSI
GSPT SP;
*end
#
*fem_results_data_on_elements
RESISTOR_CONDUCTION_CURRENT
scalar complex con_id field single global;
amps
RES_J_C
ZRES CC;
*end
#
*fem_results_data_on_elements
RESISTOR_POWER_LOSS
scalar real con_id field single global;
joule/sec
RES_POWER_LOSS
YRESR PL;
*end
#
*fem_results_data_on_nodes
SCALAR_NORMAL_CURRENT_EXCITATION
scalar complex field single global;
amps
I_EXCITATION
GPHL PHIL;
*end
#
*fem_results_data_on_nodes
SCALAR_NORMAL_CURRENT_REACTION
scalar complex field single global;
amps
I_REACTION
GPHR PHIR;
*end
#
*fem_results_data_on_elements
STORED_MAGNETIC_ENERGY
scalar real con_id field single global;
joule
MAGNETIC_ENERGY
internal_e;
*break
STORED_MAGNETIC_COENERGY
scalar real con_id field single global;
joule
MAGNETIC_COENERGY
*end
#
*fem_results_data_on_elements
STORED_MAGNETIC_ENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
MAGNETIC_ENERGY
LHXCR>LHEXR SMED;
LLNCR>LLINR SMED;
LLXCR>LLIXR SMED;
LPNCR>LPENR SMED;
LQDCR>LQUDR SMED;
LQXCR>LQDXR SMED;
LTECR>LTETR SMED;
LTRCR>LTRIR SMED;
LTXCR>LTRXR SMED;
*break
STORED_MAGNETIC_COENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
MAGNETIC_COENERGY
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
*end
#
endif
##################
# EM_TIME_DOMAIN #
##################
if (ANALYSIS = EM_TIME_DOMAIN) then
*fem_results_data_on_elements
CAPACITOR_DISPLACEMENT_CURRENT
scalar real con_id field single global;
amps
CAP_J_D
DCAP DC;
*end
#
*fem_results_data_on_elements
CAPACITOR_ELECTRIC_ENERGY
scalar real con_id field single global;
joule
CAP_ENERGY
XCAP SEE;
*end
#
*fem_results_data_on_elements
CONDUCTION_CURRENT_DENSITY
vector real con_id field single global;
amps/(meter*meter)
J_C
JHXC>JHEX CCDX CCDY CCDZ;
JLNC>JLIN CCDX CCDY CCDZ;
JLXC>JLIX CCDX CCDY CCDZ;
JPNC>JPEN CCDX CCDY CCDZ;
JQDC>JQUD CCDX CCDY CCDZ;
JQXC>JQDX CCDX CCDY CCDZ;
JTEC>JTET CCDX CCDY CCDZ;
JTRC>JTRI CCDX CCDY CCDZ;
JTXC>JTRX CCDX CCDY CCDZ;
*end
#
*fem_results_data_on_elements
DISPLACEMENT_CURRENT_DENSITY
vector real con_id field single global;
amps/(meter*meter)
J_D
KHXC>KHEX DCDX DCDY DCDZ;
KLNC>KLIN DCDX DCDY DCDZ;
KLXC>KLIX DCDX DCDY DCDZ;
KPNC>KPEN DCDX DCDY DCDZ;
KQDC>KQUD DCDX DCDY DCDZ;
KQXC>KQDX DCDX DCDY DCDZ;
KTEC>KTET DCDX DCDY DCDZ;
KTRC>KTRI DCDX DCDY DCDZ;
KTXC>KTRX DCDX DCDY DCDZ;
*end
#
*fem_results_data_on_elements
ELECTRIC_ENERGY
scalar real con_id field single global;
joule
ELECTRIC_ENERGY
internal_c;
*end
#
*fem_results_data_on_elements
ELECTRIC_ENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
ELECTRIC_ENERGY
HHXC>HHEX SEED;
HLNC>HLIN SEED;
HLXC>HLIX SEED;
HPNC>HPEN SEED;
HQDC>HQUD SEED;
HQXC>HQDX SEED;
HTEC>HTET SEED;
HTRC>HTRI SEED;
HTXC>HTRX SEED;
*end
#
*fem_results_data_on_elements
ELECTRIC_FIELD
vector real con_id field single global;
volts/meter
E
IHXC>IHEX EFX EFY EFZ;
ILNC>ILIN EFX EFY EFZ;
ILXC>ILIX EFX EFY EFZ;
IPNC>IPEN EFX EFY EFZ;
IQDC>IQUD EFX EFY EFZ;
IQXC>IQDX EFX EFY EFZ;
ITEC>ITET EFX EFY EFZ;
ITRC>ITRI EFX EFY EFZ;
ITXC>ITRX EFX EFY EFZ;
*end
#
*fem_results_data_on_elements
ELECTRIC_FLUX_DENSITY
vector real con_id field single global;
coulombs/(meter*meter)
FLUX
internal_7;
*end
#
#*fem_results_data_on_elements
#ELEMENT_VOLUME
#scalar real con_id field single global;
#meter*meter*meter
#VOLUME
#VHXC>VHEX VOL;
#VLNC>VLIN VOL;
#VLXC>VLIX VOL;
#VPNC>VPEN VOL;
#VQDC>VQUD VOL;
#VQXC>VQDX VOL;
#VTEC>VTET VOL;
#VTRC>VTRI VOL;
#VTXC>VTRX VOL;
#*end
#
*fem_results_data_on_elements
INDUCTOR_CONDUCTION_CURRENT
scalar real con_id field single global;
amps
IND_J_C
ZIND CC;
*end
#
*fem_results_data_on_elements
INDUCTOR_STORED_MAGNETIC_ENERGY
scalar real con_id field single global;
joule
IND_ENERGY
BIND SME;
*end
#
*fem_results_data_on_elements
MAGNETIC_FIELD
vector real con_id field single global;
amps/meter
H
internal_2;
*end
#
*fem_results_data_on_elements
MAGNETIC_FLUX_DENSITY
vector real con_id field single global;
wb/(meter*meter)
B
MHXC>MHEX MFDX MFDY MFDZ;
MLNC>MLIN MFDX MFDY MFDZ;
MLXC>MLIX MFDX MFDY MFDZ;
MPNC>MPEN MFDX MFDY MFDZ;
MQDC>MQUD MFDX MFDY MFDZ;
MQXC>MQDX MFDX MFDY MFDZ;
MTEC>MTET MFDX MFDY MFDZ;
MTRC>MTRI MFDX MFDY MFDZ;
MTXC>MTRX MFDX MFDY MFDZ;
*end
#
*fem_results_data_on_nodes
MAGNETIC_VECTOR_EXCITATION
vector real field single global;
amps*meter
A_EXCITATION
GVLD VLX VLY VLZ;
*end
#
if (MODEL_TYPE != AXISYMMETRIC) then
*fem_results_data_on_nodes
MAGNETIC_VECTOR_POTENTIAL
vector real field single global;
wb/meter
A
GVPT VPX VPY VPZ;
*end
endif
#
if (MODEL_TYPE = AXISYMMETRIC) then
*fem_results_data_on_nodes
MAGNETIC_VECTOR_POTENTIAL
vector real field single global;
wb/meter
A
internal_9;
*end
endif
#
*fem_results_data_on_nodes
MAGNETIC_VECTOR_REACTION
vector real field single global;
amps*meter
A_REACTION
GVRC VRX VRY VRZ;
*end
#
*fem_results_data_on_nodes
PHI_POTENTIAL
scalar real field single global;
volts
PHI
GSPD SPD;
*end
#
*fem_results_data_on_elements
POWER_LOSS
scalar real con_id field single global;
joule/sec
POWER_LOSS
internal_d;
*end
#
*fem_results_data_on_elements
POWER_LOSS_DENSITY
scalar real con_id field single global;
joule/(sec*meter*meter*meter)
POWER_LOSS
OHXC>OHEX PLD;
OLNC>OLIN PLD;
OLXC>OLIX PLD;
OPNC>OPEN PLD;
OQDC>OQUD PLD;
OQXC>OQDX PLD;
OTEC>OTET PLD;
OTRC>OTRI PLD;
OTXC>OTRX PLD;
*end
#
*fem_results_data_on_elements
POYNTING_VECTOR
vector real con_id field single global;
joule/(meter*meter)
S
internal_5;
*end
#
*fem_results_data_on_nodes
PSI_POTENTIAL
scalar real field single global;
wb
PSI
GSPT SP;
*end
#
*fem_results_data_on_elements
RESISTOR_CONDUCTION_CURRENT
scalar real con_id field single global;
amps
RES_J_C
ZRES CC;
*end
#
*fem_results_data_on_elements
RESISTOR_POWER_LOSS
scalar real con_id field single global;
joule/sec
RES_POWER_LOSS
YRES PL;
*end
#
*fem_results_data_on_nodes
SCALAR_NORMAL_CURRENT_EXCITATION
scalar real field single global;
amps
I_EXCITATION
GPHL PHIL;
*end
#
*fem_results_data_on_nodes
SCALAR_NORMAL_CURRENT_REACTION
scalar real field single global;
amps
I_REACTION
GPHR PHIR;
*end
#
*fem_results_data_on_elements
STORED_MAGNETIC_ENERGY
scalar real con_id field single global;
joule
MAGNETIC_ENERGY
internal_e;
*break
STORED_MAGNETIC_COENERGY
scalar real con_id field single global;
joule
MAGNETIC_COENERGY
*end
#
*fem_results_data_on_elements
STORED_MAGNETIC_ENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
MAGNETIC_ENERGY
LHXC>LHEX SMED;
LLNC>LLIN SMED;
LLXC>LLIX SMED;
LPNC>LPEN SMED;
LQDC>LQUD SMED;
LQXC>LQDX SMED;
LTEC>LTET SMED;
LTRC>LTRI SMED;
LTXC>LTRX SMED;
*break
STORED_MAGNETIC_COENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
MAGNETIC_COENERGY
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
*end
#
endif
############
# EM_MODAL #
############
if (ANALYSIS = EM_MODAL) then
##############
# REAL MODAL #
##############
if (APPROACH = 4) then
*fem_results_data_on_elements
CAPACITOR_CURRENT
scalar real con_id field single global;
amps
CAP_I
DCAP DC;
*end
#
*fem_results_data_on_elements
DISPLACEMENT_CURRENT_DENSITY
vector real con_id field single global;
amps/(meter*meter)
J_D
KHXC>KHEX DCDX DCDY DCDZ;
KLNC>KLIN DCDX DCDY DCDZ;
KLXC>KLIX DCDX DCDY DCDZ;
KPNC>KPEN DCDX DCDY DCDZ;
KQDC>KQUD DCDX DCDY DCDZ;
KQXC>KQDX DCDX DCDY DCDZ;
KTEC>KTET DCDX DCDY DCDZ;
KTRC>KTRI DCDX DCDY DCDZ;
KTXC>KTRX DCDX DCDY DCDZ;
*end
#
*fem_results_data_on_elements
ELECTRIC_ENERGY
scalar real con_id field single global;
joule
ELECTRIC_ENERGY
internal_c;
*end
#
*fem_results_data_on_elements
ELECTRIC_ENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
ELECTRIC_ENERGY
HHXC>HHEX SEED;
HLNC>HLIN SEED;
HLXC>HLIX SEED;
HPNC>HPEN SEED;
HQDC>HQUD SEED;
HQXC>HQDX SEED;
HTEC>HTET SEED;
HTRC>HTRI SEED;
HTXC>HTRX SEED;
*end
#
*fem_results_data_on_elements
ELECTRIC_FIELD
vector real con_id field single global;
volts/meter
E
IHXC>IHEX EFX EFY EFZ;
ILNC>ILIN EFX EFY EFZ;
ILXC>ILIX EFX EFY EFZ;
IPNC>IPEN EFX EFY EFZ;
IQDC>IQUD EFX EFY EFZ;
IQXC>IQDX EFX EFY EFZ;
ITEC>ITET EFX EFY EFZ;
ITRC>ITRI EFX EFY EFZ;
ITXC>ITRX EFX EFY EFZ;
*end
#
*fem_results_data_on_elements
ELECTRIC_FLUX_DENSITY
vector real con_id field single global;
coulombs/(meter*meter)
FLUX
internal_7;
*end
#
#*fem_results_data_on_elements
#ELEMENT_VOLUME
#scalar real con_id field single global;
#meter*meter*meter
#VOLUME
#VHXC>VHEX VOL;
#VLNC>VLIN VOL;
#VLXC>VLIX VOL;
#VPNC>VPEN VOL;
#VQDC>VQUD VOL;
#VQXC>VQDX VOL;
#VTEC>VTET VOL;
#VTRC>VTRI VOL;
#VTXC>VTRX VOL;
#*end
#
*fem_results_data_on_elements
INDUCTOR_CONDUCTION_CURRENT
scalar real con_id field single global;
amps
IND_J_C
ZIND CC;
*end
#
*fem_results_data_on_elements
INDUCTOR_STORED_MAGNETIC_ENERGY
scalar real con_id field single global;
joule
IND_ENERGY
BIND SME;
*end
#
*fem_results_data_on_elements
MAGNETIC_FIELD
vector real con_id field single global;
amps/meter
H
internal_2;
*end
#
*fem_results_data_on_elements
MAGNETIC_FLUX_DENSITY
vector real con_id field single global;
wb/(meter*meter)
B
MHXC>MHEX MFDX MFDY MFDZ;
MLNC>MLIN MFDX MFDY MFDZ;
MLXC>MLIX MFDX MFDY MFDZ;
MPNC>MPEN MFDX MFDY MFDZ;
MQDC>MQUD MFDX MFDY MFDZ;
MQXC>MQDX MFDX MFDY MFDZ;
MTEC>MTET MFDX MFDY MFDZ;
MTRC>MTRI MFDX MFDY MFDZ;
MTXC>MTRX MFDX MFDY MFDZ;
*end
#
if (MODEL_TYPE != AXISYMMETRIC) then
*fem_results_data_on_nodes
MAGNETIC_VECTOR_POTENTIAL
vector real field single global;
wb/meter
A
GVPT VPX VPY VPZ;
*end
endif
#
if (MODEL_TYPE = AXISYMMETRIC) then
*fem_results_data_on_nodes
MAGNETIC_VECTOR_POTENTIAL
vector real field single global;
wb/meter
A
internal_9;
*end
endif
#
*fem_results_data_on_nodes
MAGNETIC_VECTOR_REACTION
vector real field single global;
amps*meter
A_REACTION
GVRC VRX VRY VRZ;
*end
#
*fem_results_data_on_nodes
PSI_POTENTIAL
scalar real field single global;
wb
PSI
GSPT SP;
*end
#
*fem_results_data_on_nodes
SCALAR_NORMAL_CURRENT_REACTION
scalar real field single global;
amps
I_REACTION
GPHR PHIR;
*end
#
*fem_results_data_on_elements
STORED_MAGNETIC_ENERGY
scalar real con_id field single global;
joule
MAGNETIC_ENERGY
internal_e;
*break
STORED_MAGNETIC_COENERGY
scalar real con_id field single global;
joule
MAGNETIC_COENERGY
*end
#
*fem_results_data_on_elements
STORED_MAGNETIC_ENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
MAGNETIC_ENERGY
LHXC>LHEX SMED;
LLNC>LLIN SMED;
LLXC>LLIX SMED;
LPNC>LPEN SMED;
LQDC>LQUD SMED;
LQXC>LQDX SMED;
LTEC>LTET SMED;
LTRC>LTRI SMED;
LTXC>LTRX SMED;
*break
STORED_MAGNETIC_COENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
MAGNETIC_COENERGY
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
*end
#
endif
#################
# COMPLEX MODAL #
#################
if (APPROACH = 7) then
*fem_results_data_on_elements
CAPACITOR_DISPLACEMENT_CURRENT
scalar complex con_id field single global;
amps
CAP_J_D
DCAP DC;
*end
#
*fem_results_data_on_elements
CAPACITOR_ELECTRIC_ENERGY
scalar real con_id field single global;
joule
CAP_ENERGY
XCAPR SEE;
*end
#
*fem_results_data_on_elements
CONDUCTION_CURRENT_DENSITY
vector complex con_id field single global;
amps/(meter*meter)
J_C
JHXC>JHEX CCDX CCDY CCDZ;
JLNC>JLIN CCDX CCDY CCDZ;
JLXC>JLIX CCDX CCDY CCDZ;
JPNC>JPEN CCDX CCDY CCDZ;
JQDC>JQUD CCDX CCDY CCDZ;
JQXC>JQDX CCDX CCDY CCDZ;
JTEC>JTET CCDX CCDY CCDZ;
JTRC>JTRI CCDX CCDY CCDZ;
JTXC>JTRX CCDX CCDY CCDZ;
*end
#
*fem_results_data_on_elements
DISPLACEMENT_CURRENT_DENSITY
vector complex con_id field single global;
amps/(meter*meter)
J_D
KHXC>KHEX DCDX DCDY DCDZ;
KLNC>KLIN DCDX DCDY DCDZ;
KLXC>KLIX DCDX DCDY DCDZ;
KPNC>KPEN DCDX DCDY DCDZ;
KQDC>KQUD DCDX DCDY DCDZ;
KQXC>KQDX DCDX DCDY DCDZ;
KTEC>KTET DCDX DCDY DCDZ;
KTRC>KTRI DCDX DCDY DCDZ;
KTXC>KTRX DCDX DCDY DCDZ;
*end
#
*fem_results_data_on_elements
ELECTRIC_ENERGY
scalar real con_id field single global;
joule
ELECTRIC_ENERGY
internal_c;
*end
#
*fem_results_data_on_elements
ELECTRIC_ENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
ELECTRIC_ENERGY
HHXCR>HHEXR SEED;
HLNCR>HLINR SEED;
HLXCR>HLIXR SEED;
HPNCR>HPENR SEED;
HQDCR>HQUDR SEED;
HQXCR>HQDXR SEED;
HTECR>HTETR SEED;
HTRCR>HTRIR SEED;
HTXCR>HTRXR SEED;
*end
#
*fem_results_data_on_elements
ELECTRIC_FIELD
vector complex con_id field single global;
volts/meter
E
IHXC>IHEX EFX EFY EFZ;
ILNC>ILIN EFX EFY EFZ;
ILXC>ILIX EFX EFY EFZ;
IPNC>IPEN EFX EFY EFZ;
IQDC>IQUD EFX EFY EFZ;
IQXC>IQDX EFX EFY EFZ;
ITEC>ITET EFX EFY EFZ;
ITRC>ITRI EFX EFY EFZ;
ITXC>ITRX EFX EFY EFZ;
*end
#
*fem_results_data_on_elements
ELECTRIC_FLUX_DENSITY
vector complex con_id field single global;
coulombs/(meter*meter)
FLUX
internal_8;
*end
#
#*fem_results_data_on_elements
#ELEMENT_VOLUME
#scalar real con_id field single global;
#meter*meter*meter
#VOLUME
#VHXCR>VHEXR VOL;
#VLNCR>VLINR VOL;
#VLXCR>VLIXR VOL;
#VPNCR>VPENR VOL;
#VQDCR>VQUDR VOL;
#VQXCR>VQDXR VOL;
#VTECR>VTETR VOL;
#VTRCR>VTRIR VOL;
#VTXCR>VTRXR VOL;
#*end
#
*fem_results_data_on_elements
INDUCTOR_CONDUCTION_CURRENT
scalar complex con_id field single global;
amps
IND_J_C
ZIND CC;
*end
#
*fem_results_data_on_elements
INDUCTOR_STORED_MAGNETIC_ENERGY
scalar real con_id field single global;
joule
IND_ENERGY
BINDR SME;
*end
#
*fem_results_data_on_elements
MAGNETIC_FIELD
vector complex con_id field single global;
amps/meter
H
internal_3;
*end
#
*fem_results_data_on_elements
MAGNETIC_FLUX_DENSITY
vector complex con_id field single global;
wb/(meter*meter)
B
MHXC>MHEX MFDX MFDY MFDZ;
MLNC>MLIN MFDX MFDY MFDZ;
MLXC>MLIX MFDX MFDY MFDZ;
MPNC>MPEN MFDX MFDY MFDZ;
MQDC>MQUD MFDX MFDY MFDZ;
MQXC>MQDX MFDX MFDY MFDZ;
MTEC>MTET MFDX MFDY MFDZ;
MTRC>MTRI MFDX MFDY MFDZ;
MTXC>MTRX MFDX MFDY MFDZ;
*end
#
if (MODEL_TYPE != AXISYMMETRIC) then
*fem_results_data_on_nodes
MAGNETIC_VECTOR_POTENTIAL
vector complex field single global;
wb/meter
A
GVPT VPX VPY VPZ;
*end
endif
#
if (MODEL_TYPE = AXISYMMETRIC) then
*fem_results_data_on_nodes
MAGNETIC_VECTOR_POTENTIAL
vector complex field single global;
wb/meter
A
internal_a;
*end
endif
#
*fem_results_data_on_nodes
MAGNETIC_VECTOR_REACTION
vector complex field single global;
amps*meter
A_REACTION
GVRC VRX VRY VRZ;
*end
#
*fem_results_data_on_elements
POWER_LOSS
scalar real con_id field single global;
joule/sec
POWER_LOSS
internal_d;
*end
#
*fem_results_data_on_elements
POWER_LOSS_DENSITY
scalar real con_id field single global;
joule/(sec*meter*meter*meter)
POWER_LOSS
OHXCR>OHEXR PLD;
OLNCR>OLINR PLD;
OLXCR>OLIXR PLD;
OPNCR>OPENR PLD;
OQDCR>OQUDR PLD;
OQXCR>OQDXR PLD;
OTECR>OTETR PLD;
OTRCR>OTRIR PLD;
OTXCR>OTRXR PLD;
*end
#
*fem_results_data_on_nodes
PSI_POTENTIAL
scalar complex field single global;
wb
PSI
GSPT SP;
*end
#
*fem_results_data_on_elements
RESISTOR_CONDUCTION_CURRENT
scalar complex con_id field single global;
amps
RES_J_C
ZRES CC;
*end
#
*fem_results_data_on_elements
RESISTOR_POWER_LOSS
scalar real con_id field single global;
joule/sec
RES_POWER_LOSS
YRESR PL;
*end
#
*fem_results_data_on_nodes
SCALAR_NORMAL_CURRENT_REACTION
scalar complex field single global;
amps
I_REACTION
GPHR PHIR;
*end
#
*fem_results_data_on_elements
STORED_MAGNETIC_ENERGY
scalar real con_id field single global;
joule
MAGNETIC_ENERGY
internal_e;
*break
STORED_MAGNETIC_COENERGY
scalar real con_id field single global;
joule
MAGNETIC_COENERGY
*end
#
*fem_results_data_on_elements
STORED_MAGNETIC_ENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
MAGNETIC_ENERGY
LHXCR>LHEXR SMED;
LLNCR>LLINR SMED;
LLXCR>LLIXR SMED;
LPNCR>LPENR SMED;
LQDCR>LQUDR SMED;
LQXCR>LQDXR SMED;
LTECR>LTETR SMED;
LTRCR>LTRIR SMED;
LTXCR>LTRXR SMED;
*break
STORED_MAGNETIC_COENERGY_DENSITY
scalar real con_id field single global;
joule/(meter*meter*meter)
MAGNETIC_COENERGY
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
SMCD;
*end
#
endif
endif
##############
# EM_THERMAL #
##############
if (ANALYSIS = TRANSIENT_HEAT_TRANSFER) then
#
*fem_results_data_on_nodes
TEMPERATURES
scalar real field single global;
celsius
TEMPERATURE
THERR TEMP;
*end
#
*fem_results_data_on_elements
THERMAL_GRADIENT
vector real con_id field single global;
celsius/meter
GRADIENT
QTR3R XGRAD YGRAD ZGRAD;
QQD4R XGRAD YGRAD ZGRAD;
QTR6R XGRAD YGRAD ZGRAD;
QTX6R XGRAD YGRAD ZGRAD;
QQD8R XGRAD YGRAD ZGRAD;
QTETR XGRAD YGRAD ZGRAD;
QPENR XGRAD YGRAD ZGRAD;
QHEXR XGRAD YGRAD ZGRAD;
*break
THERMAL_FLUX
vector real con_id field single global;
joule/(sec*meter*meter)
FLUX
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
XFLUX YFLUX ZFLUX;
*end
endif
################
# SMALL_MOTION #
################
if (ANALYSIS = NONLINEAR_TRANSIENT) THEN
*fem_results_data_on_nodes
DISPLACEMENT
vector real field single global;
meter
DELTA
DISP DT1 DT2 DT3;
*end
#
*fem_results_data_on_nodes
VELOCITY
vector real field single global;
meter/sec
DELTA
VELO VT1 VT2 VT3;
*end
#
*fem_results_data_on_nodes
ACCELERATION
vector real field single global;
meter/(sec*sec)
DELTA
ACCE AT1 AT2 AT3;
*end
#
if (MODEL_TYPE = PLANE_STRAIN) then
*fem_results_data_on_elements
STRESS
sym_tensor real con_id field single global;
newton/(meter*meter)
SIGMA
NQD4   SX1 SY1 SZ1 T1 0 0  |
  SQD4 SX1 SY1 0   T1 0 0;
NTR3   SX1 SY1 SZ1 T1 0 0  |
  STR3 SX1 SY1 0 T1 0 0;
SQDR   SX1 SY1 0 T1 0 0;
STRR   SX1 SY1 0 T1 0 0;
SQD8   SX1 SY1 0 T1 0 0;
STR6   SX1 SY1 0 T1 0 0;
NHEX SX SY SZ TXY TYZ TZX  |  SHEX SX SY SZ TXY TYZ TZX;
NPEN SX SY SZ TXY TYZ TZX  |  SPEN SX SY SZ TXY TYZ TZX;
NTET SX SY SZ TXY TYZ TZX  |  STET SX SY SZ TXY TYZ TZX;
endif
if (MODEL_TYPE != PLANE_STRAIN) then
*fem_results_data_on_elements
STRESS
sym_tensor real con_id field multiple global;
newton/(meter*meter)
SIGMA
NQD4   SX2 SY2 SZ2 T2 0 0   SX1 SY1 SZ1 T1 0 0  |
  SQD4 SX2 SY2 0   T2 0 0   SX1 SY1 0   T1 0 0;
NTR3   SX2 SY2 SZ2 T2 0 0   SX1 SY1 SZ1 T1 0 0  |
  STR3 SX2 SY2 0 T2 0 0     SX1 SY1 0 T1 0 0;
SQDR   SX2 SY2 0 T2 0 0     SX1 SY1 0 T1 0 0;
STRR   SX2 SY2 0 T2 0 0     SX1 SY1 0 T1 0 0;
SQD8   SX2 SY2 0 T2 0 0     SX1 SY1 0 T1 0 0;
STR6   SX2 SY2 0 T2 0 0     SX1 SY1 0 T1 0 0;
NHEX SX SY SZ TXY TYZ TZX  |  SHEX SX SY SZ TXY TYZ TZX;
NPEN SX SY SZ TXY TYZ TZX  |  SPEN SX SY SZ TXY TYZ TZX;
NTET SX SY SZ TXY TYZ TZX  |  STET SX SY SZ TXY TYZ TZX;
*end
endif
*fem_results_data_on_elements
STRESS
sym_tensor real con_id field single global;
newton/(meter*meter)
SIGMA
STX6 RS AXS AS SS 0 0;
*end
#
endif
endif
